OC.L10N.register(
    "core",
    {
    "Please select a file." : "请选择一个文件",
    "File is too big" : "文件太大",
    "Invalid file provided" : "提供的文件无效",
    "No image or file provided" : "没有提供图片或文件",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "An error occurred. Please contact your admin." : "发生了一个错误，请联系管理员。",
    "No temporary profile picture available, try again" : "没有临时概览页图片可用，请重试",
    "No crop data provided" : "没有提供相应数据",
    "No valid crop data provided" : "没有提供有效的裁剪数据",
    "Crop is not square" : "裁剪的不是正方形",
    "Could not reset password because the token is invalid" : "无法重置密码，因为该令牌无效。",
    "Could not reset password because the token expired" : "无法重置密码，因为该令牌已过期。",
    "Could not reset password because the token does not match" : "因令牌不符无法重置密码",
    "%s password changed successfully" : "%s 密码修改成功",
    "%s password reset" : "重置 %s 的密码",
    "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
    "Download / View" : "下载 / 查看",
    "Recipients can view or download contents." : "接收者可查看或下载内容。",
    "Download / View / Upload" : "下载 / 查看 / 上传",
    "Recipients can view, download and upload contents." : "接收者可查看、下载以及上传内容。",
    "Download / View / Edit" : "下载 / 查看 / 编辑",
    "Recipients can view, download, edit, delete and upload contents." : "接收者可查看、下载、编辑、删除以及上传内容。",
    "Upload only" : "仅上传",
    "Receive files from multiple recipients without revealing the contents of the folder." : "从多个接收者处接收文件而不暴露文件夹中的内容。",
    "Preparing update" : "正在准备更新",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "修复警告：",
    "Repair error: " : "修复错误：",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "由于自动更新在 config.php 中已禁用，请使用命令行更新。",
    "[%d / %d]: Checking table %s" : "[%d / %d]: 检查数据表 %s",
    "Turned on maintenance mode" : "启用维护模式",
    "Turned off maintenance mode" : "关闭维护模式",
    "Maintenance mode is kept active" : "维护模式已被启用",
    "Updating database schema" : "正在更新数据库架构",
    "Updated database" : "数据库已更新",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "检查数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
    "Checked database schema update" : "已经检查数据库架构更新",
    "Checking updates of apps" : "检查更新应用",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "检查 %s 的数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
    "Checked database schema update for apps" : "已经检查应用的数据库架构更新",
    "Updated \"%s\" to %s" : "更新 \"%s\" 为 %s",
    "Set log level to debug" : "设置日志级别为 调试",
    "Reset log level" : "重设日志级别",
    "Starting code integrity check" : "开始代码完整性检查",
    "Finished code integrity check" : "代码完整性检查完成",
    "%s (3rdparty)" : "%s (第三方)",
    "%s (incompatible)" : "%s (不兼容)",
    "Following apps have been disabled: %s" : "下列应用已经被禁用：%s",
    "Already up to date" : "已经是最新",
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sun." : "日",
    "Mon." : "周一",
    "Tue." : "周二",
    "Wed." : "周三",
    "Thu." : "周四",
    "Fri." : "周五",
    "Sat." : "周六",
    "Su" : "Su",
    "Mo" : "Mo",
    "Tu" : "Tu",
    "We" : "We",
    "Th" : "Th",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "一月",
    "Feb." : "二月",
    "Mar." : "三月",
    "Apr." : "四月",
    "May." : "五月",
    "Jun." : "六月",
    "Jul." : "七月",
    "Aug." : "八月",
    "Sep." : "九月",
    "Oct." : "十月",
    "Nov." : "十一月",
    "Dec." : "十二月",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">代码完整性检查出现异常，点击查看详细信息...</a>",
    "Settings" : "设置",
    "Problem loading page, reloading in 5 seconds" : "加载页面出现问题，在 5 秒内重新载入",
    "Saving..." : "保存中...",
    "Dismiss" : "忽略",
    "seconds ago" : "几秒前",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "密码重置邮件已经发送到您的电子邮箱中。如果您长时间没能收到邮件，请检查您的垃圾/广告邮件箱。<br>如果未能收到邮件请联系管理员。",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已被加密。如果您没有启用恢复密钥，密码重置后您将无法取回您的文件。<br />在继续之前，如果有疑问请联系您的管理员。<br />确认继续？",
    "I know what I'm doing" : "我知道我在做什么",
    "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
    "Error adding {addItem}: {addItem} already exists" : "添加{addItem}时发生错误：{addItem}已经存在",
    "No" : "否",
    "Yes" : "是",
    "Choose" : "选择",
    "Error loading file picker template: {error}" : "加载文件分拣模板出错: {error}",
    "Ok" : "确定",
    "Error loading message template: {error}" : "加载消息模板出错: {error}",
    "read-only" : "只读",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 个文件冲突"],
    "One file conflict" : "1个文件冲突",
    "New Files" : "新文件",
    "Already existing files" : "已经存在的文件",
    "Which files do you want to keep?" : "想要保留哪一个文件呢？",
    "If you select both versions, the copied file will have a number added to its name." : "如果同时选择了两个版本，复制的文件名将会增加上一个数字。",
    "Cancel" : "取消",
    "Continue" : "继续",
    "(all selected)" : "(选中全部)",
    "({count} selected)" : "(选择了{count}个)",
    "Error loading file exists template" : "加载文件存在性模板失败",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "由于 WebDAV 接口似乎被破坏，因此你的网页服务器没有正确地设置来允许文件同步。",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "您的web服务器未正确设置以解析 \"{url}\"。您可以在我们的<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>中找到更多可用信息。",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "此服务器上没有可用的因特网连接. 这意味着某些特性将无法工作，例如挂载外部存储器, 提醒更新或安装第三方应用等. 从远程访问文件和发送提醒电子邮件也可能无法工作. 如果你想要ownCloud的所有特性, 我们建议启用此服务器的因特网连接.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "内存缓存未配置。如果可用，请配置 memcache 来增强性能。更多信息请查看我们的<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a> 。",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom 无法被 PHP 读取，出于安全原因，这是强烈不推荐的。请查看<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>了解详情。",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "你的 PHP 版本 ({version}) 不再被 <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\"> PHP </a>支持。我们建议您升级您的PHP版本，以便获得 PHP 性能和安全提升。",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "反向代理头配置不正确，或者您正从一个受信任的代理访问ownCloud。如果你不是通过受信任的代理访问 ownCloud，这将引发一个安全问题，可能由于 ownCloud IP 地址可见导致欺骗攻击。更多信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached 配置为分布式缓存，但是已经安装的 PHP 模块是 \"memcache\" 。 \\OC\\Memcache\\Memcached 仅支持 \"memcached\" 而不是 \"memcache\"。点击 <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\"> memcached wiki 了解两个模块的不同</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "一些文件没有通过完整性检查。如何解决此问题的详细信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">无效文件列表…</a> / <a href=\"{rescanEndpoint}\">重新扫描…</a>)",
    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "你在以 DEBUG 模式运行，这可能导致意外的副作用。请从 \"config.php\" 文件中移除 \"debug\" 标识。",
    "Error occurred while checking server setup" : "当检查服务器启动时出错",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "你的数据目录和你的文件可能从互联网被访问到。.htaccess 文件不工作。我们强烈建议你配置你的网页服务器，使数据目录不再可访问，或者将数据目录移动到网页服务器根文档目录之外。",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 头部没有配置和 \"{expected}\" 的一样。这是一个潜在的安全或者隐私风险，我们调整这项设置。",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP 严格传输安全（Strict-Transport-Security）报头未配置到至少“{seconds}”秒。处于增强安全性考虑，我们推荐按照<a href=\"{docUrl}\" rel=\"noreferrer\">安全提示</a>启用 HSTS。",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "您正在通过 HTTP 访问该站点，我们强烈建议您按照<a href=\"{docUrl}\">安全提示</a>配置服务器强制使用 HTTPS。",
    "Shared" : "已共享",
    "Shared with {recipients}" : "分享给{recipients}",
    "Error" : "错误",
    "Error while sharing" : "共享时出错",
    "Error while unsharing" : "取消共享时出错",
    "The public link will expire no later than {days} days after it is created" : "这个共享链接将在创建后 {days} 天失效",
    "Expiration" : "过期",
    "Choose an expiration date" : "选择过期日期",
    "Expiration date is required" : "到期日期为必填",
    "Delete {link}" : "删除 {link}",
    "Remove link" : "移除链接",
    "Link" : "链接",
    "Create public link" : "创建公共链接",
    "Edit" : "编辑",
    "Remove" : "移除",
    "Copy to clipboard" : "复制到剪贴板 ",
    "Social share" : "社交分享",
    "There are currently no link shares, you can create one" : "目前没有共享链接，您可以创建一个",
    "Anyone with the link has access to the file/folder" : "任何查看此链接的人都可以访问文件、文件夹",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按⌘-C复制",
    "Press Ctrl-C to copy." : "按Ctrl-C复制",
    "Choose a password" : "选择一个密码",
    "Password required" : "要求输入密码",
    "Link name" : "链接名称",
    "Name" : "名称",
    "Filename" : "文件名",
    "Password" : "密码",
    "Can not remove required password" : "无法移除要求的密码",
    "Edit link share: {name}" : "编辑共享链接： {name}",
    "Create link share: {name}" : "创建共享链接： {name}",
    "Share" : "分享",
    "Save" : "保存",
    "Remove password" : "去除密码",
    "Share to Twitter. Opens in a new window." : "分享到Twitter。在新窗口中打开。",
    "Share to Facebook. Opens in a new window." : "分享到Facebook。在新窗口中打开。",
    "Share to Diaspora. Opens in a new window." : "分享到Diaspora。在新窗口中打开。",
    "Share to Google+. Opens in a new window." : "分享到Google+。在新窗口中打开。",
    "Share via email. Opens your mail client." : "通过邮件分享。打开邮件客户端。",
    "Email link to person" : "发送链接到个人",
    "Send copy to self" : "发送副本给自己。",
    "Send link via email" : "通过邮件发送链接",
    "Add personal message" : "增加个人信息",
    "Sending" : "发送中",
    "E-Mail sent" : "邮件已发送",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 组",
    "Shared with you by {owner}" : "{owner} 与您共享",
    "group" : "群组",
    "federated" : "联合",
    "notify by email" : "以邮件通知",
    "Unshare" : "取消共享",
    "can share" : "可共享",
    "can edit" : "可以修改",
    "create" : "创建",
    "change" : "更改",
    "delete" : "删除",
    "access control" : "访问控制",
    "Could not unshare" : "无法共享",
    "Email notification was sent!" : "电子邮件通知已发送！",
    "Email notification not sent" : "电子邮件通知未发送",
    "Share details could not be loaded for this item." : "无法加载这个项目的分享详情",
    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
    "No users found for {search}" : "没有找到 {search} 用户",
    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["请输入至少 {chars} 字符作为建议"],
    "An error occurred. Please try again" : "发生错误。请重试。",
    "User" : "用户",
    "Group" : "群组",
    "Guest" : "访客",
    "At {server}" : "位于 {server}",
    "Federated" : "联合",
    "User and Groups" : "用户和组",
    "Public Links" : "公共链接",
    "Sharing is not allowed" : "禁止分享",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "使用语法 username@example.com/owncloud 分享给其他 ownCloud 上的用户",
    "Share with users…" : "与用户分享...",
    "Share with users, groups or remote users…" : "与用户，组或远程用户分享...",
    "Share with users or groups…" : "与用户或组分享...",
    "Share with users or remote users…" : "与用户或远程用户分享...",
    "Error removing share" : "移除分享时出错",
    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
    "restricted" : "受限",
    "invisible" : "不可见",
    "Static" : "静态的",
    "({scope})" : "({scope})",
    "Delete" : "删除",
    "Rename" : "重命名",
    "Collaborative tags" : "协作标签",
    "The object type is not specified." : "未指定对象类型。",
    "Enter new" : "输入新...",
    "Add" : "增加",
    "Edit tags" : "编辑标签",
    "Error loading dialog template: {error}" : "加载对话框模板出错: {error}",
    "No tags selected for deletion." : "请选择要删除的标签。",
    "unknown text" : "未知文字",
    "Hello world!" : "Hello world!",
    "sunny" : "晴",
    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是{weather}",
    "Hello {name}" : "你好 {name}",
    "new" : "新建",
    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "正在升级，在某些环境下离开此网页可能导致升级中断。",
    "Updating to {version}" : "正在升级到 {version}",
    "An error occurred." : "发生了一个错误",
    "Please reload the page." : "请重新加载页面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新不成功。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "更新不成功。请汇报将此问题汇报给  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud 社区</a>。",
    "The update was successful. There were warnings." : "更新成功。有警告。",
    "The update was successful. Redirecting you to ownCloud now." : "更新成功。正在重定向至 ownCloud。",
    "Searching other places" : "搜索其他地方",
    "No search results in other folders" : "在其他文件夹中没有得到任何搜索结果",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["在其他文件夹中找到 {count} 条搜索结果"],
    "Personal" : "个人",
    "Users" : "用户",
    "Apps" : "应用",
    "Admin" : "管理",
    "Help" : "帮助",
    "Access forbidden" : "访问禁止",
    "File not found" : "文件未找到",
    "The specified document has not been found on the server." : "在服务器上没找到指定的文件。",
    "You can click here to return to %s." : "你可以点击这里返回 %s。",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "嗨、你好,\n\n只想让你知道 %s 分享了 %s 给你。\n现在查看: %s\n",
    "The share will expire on %s." : "此分享将在 %s 过期。",
    "Personal note from the sender: \n %s." : "来自发送者的个人留言：\n %s.",
    "Cheers!" : "干杯！",
    "Internal Server Error" : "内部服务器错误",
    "The server encountered an internal error and was unable to complete your request." : "服务器发送一个内部错误并且无法完成你的请求。",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "如果此错误多次复现请联系服务器管理员，并在报告中包含以下技术细节。",
    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "更多细节可在 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">服务器日志</a>找到。",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址： %s",
    "Request ID: %s" : "请求 ID: %s",
    "Type: %s" : "类型：%s",
    "Code: %s" : "代码: %s",
    "Message: %s" : "消息: %s",
    "File: %s" : "文件: %s",
    "Line: %s" : "行: %s",
    "Trace" : "追踪",
    "Imprint" : "版本说明",
    "Privacy Policy" : "隐私政策",
    "Create an <strong>admin account</strong>" : "创建<strong>管理员账号</strong>",
    "Username" : "用户名",
    "Storage & database" : "存储 & 数据库",
    "Data folder" : "数据目录",
    "Configure the database" : "配置数据库",
    "Only %s is available." : "仅 %s 可用。",
    "Install and activate additional PHP modules to choose other database types." : "安装或激活额外的 PHP 模块以选择其他数据库类型。",
    "For more details check out the documentation." : "请查阅文档获得详细信息。",
    "Database user" : "数据库用户",
    "Database password" : "数据库密码",
    "Database name" : "数据库名",
    "Database tablespace" : "数据库表空间",
    "Database host" : "数据库主机",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "请指定端口号以及主机名 (例如 localhost:5432)。",
    "Performance warning" : "性能警告",
    "SQLite will be used as database." : "SQLite 将被作为数据库使用。",
    "For larger installations we recommend to choose a different database backend." : "对于更大的安装，我们建议选择一个不同的数据库后端。",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite 。",
    "Finish setup" : "安装完成",
    "Finishing …" : "即将完成 ...",
    "Need help?" : "需要帮助？",
    "See the documentation" : "查看文档",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "嗨、你好,<br><br>只想让你知道 %s 分享了 <strong>%s</strong> 给你。<br><a href=\"%s\">现在查看！</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用要求 JavaScript 。请 {linkstart} 打开 JavaScript {linkend} ，然后重新载入页面。",
    "Menu" : "菜单",
    "Log out" : "注销",
    "Search" : "搜索",
    "Server side authentication failed!" : "服务端验证失败！",
    "Please contact your administrator." : "请联系你的管理员。",
    "An internal error occurred." : "发生了内部错误。",
    "Please try again or contact your administrator." : "请重试或联系管理员。",
    "Login" : "登录",
    "Username or email" : "用户名或邮箱",
    "Wrong password. Reset it?" : "密码错误。要重置么？",
    "Wrong password." : "密码错误",
    "You are trying to access a private link. Please log in first." : "您在尝试访问私有链接，请先登录。",
    "Stay logged in" : "保持登录",
    "Alternative Logins" : "其他登录方式",
    "Use the following link to reset your password: {link}" : "使用以下链接重置您的密码：{link}",
    "Password changed successfully" : "密码已成功修改",
    "New password" : "新密码",
    "New Password" : "新密码",
    "Confirm Password" : "确认密码",
    "Reset password" : "重置密码",
    "Personal note from the sender: <br> %s." : "来自发送者的个人留言：<br> %s.",
    "This ownCloud instance is currently in single user mode." : "当前ownCloud实例运行在单用户模式下。",
    "This means only administrators can use the instance." : "这意味着只有管理员才能在实例上操作。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系你的系统管理员。",
    "Thank you for your patience." : "感谢让你久等了。",
    "Two-step verification" : "两步验证",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "您的帐户已启用增强安全性，请使用第二因子验证。",
    "Cancel login" : "取消登录",
    "Please authenticate using the selected factor." : "请使用所选择的因素验证。",
    "An error occurred while verifying the token" : "在验证令牌时出错",
    "You are accessing the server from an untrusted domain." : "您正在访问来自不信任域名的服务器。",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "请联系你的系统管理员。如果你是系统管理员，配置 config/config.php 文件中参数 \"trusted_domain\" 设置。",
    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "一个示例配置在 config/config.sample.php 文件或 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>中有提供。",
    "App update required" : "必须的应用更新",
    "%s will be updated to version %s" : "%s 将会更新至版本 %s",
    "These apps will be updated:" : "以下应用将被更新：",
    "The theme %s has been disabled." : "%s 主题已被禁用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
    "Start update" : "开始更新",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为进行避免较大的安装时超时，你可以在你的安装目录下运行下面的命令：",
    "Detailed logs" : "详细日志",
    "Update needed" : "需要更新",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "您的实例可能包含较多文件和/或用户，为保证更新过程流畅，请使用命令行更新工具 (occ upgrade)。",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "自动更新在 config.php 中被禁用，请使用命令行更新工具 (occ upgrade) 升级您的实例。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "该 %s 实例当前处于维护模式，这将进行一些时间。",
    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。"
},
"nplurals=1; plural=0;");
